@@ -40,6 +40,8 @@
 #include <xmlsec/openssl/evp.h>
 #include <xmlsec/openssl/x509.h>
 
+#include "openssl_compat.h"
+
 static int      xmlSecOpenSSLAppLoadRANDFile            (const char *filename);
 static int      xmlSecOpenSSLAppSaveRANDFile            (const char *filename);
 static int      xmlSecOpenSSLDefaultPasswordCallback    (char *buf,
@@ -76,14 +78,15 @@ xmlSecOpenSSLAppInit(const char* config) {
 
 #else /* !defined(XMLSEC_OPENSSL_API_110) */
     int ret;
-
-    ret = OPENSSL_init_crypto(OPENSSL_INIT_LOAD_CRYPTO_STRINGS | 
+    uint64_t opts = OPENSSL_INIT_LOAD_CRYPTO_STRINGS |
                               OPENSSL_INIT_ADD_ALL_CIPHERS |
                               OPENSSL_INIT_ADD_ALL_DIGESTS |
-                              OPENSSL_INIT_LOAD_CONFIG |
-                              OPENSSL_INIT_ASYNC |
-                              OPENSSL_INIT_ENGINE_ALL_BUILTIN,
-                              NULL);
+                              OPENSSL_INIT_LOAD_CONFIG;
+#ifndef OPENSSL_IS_BORINGSSL
+    opts |= OPENSSL_INIT_ASYNC | OPENSSL_INIT_ENGINE_ALL_BUILTIN;
+#endif /* OPENSSL_IS_BORINGSSL */
+
+    ret = OPENSSL_init_crypto(opts, NULL);
     if(ret != 1) {
         xmlSecOpenSSLError("OPENSSL_init_crypto", NULL);
         return(-1);
@@ -128,6 +131,7 @@ xmlSecOpenSSLAppShutdown(void) {
 
     ENGINE_cleanup();
     CONF_modules_unload(1);
+
     CRYPTO_cleanup_all_ex_data();
     ERR_remove_thread_state(NULL);
     ERR_free_strings();
