@@ -399,11 +399,11 @@ xmlSecEncCtxXmlEncrypt(xmlSecEncCtxPtr encCtx, xmlNodePtr tmpl, xmlNodePtr node)
 
     /* now we need to update our original document */
     if((encCtx->type != NULL) && xmlStrEqual(encCtx->type, xmlSecTypeEncElement)) {
-        /* check if we need to return the replaced node */
+    	/* check if we need to return the replaced node */
         if((encCtx->flags & XMLSEC_ENC_RETURN_REPLACED_NODE) != 0) {
             ret = xmlSecReplaceNodeAndReturn(node, tmpl, &(encCtx->replacedNodeList));
             if(ret < 0) {
-                xmlSecInternalError("xmlSecReplaceNode",
+                xmlSecInternalError("xmlSecReplaceNodeAndReturn",
                                     xmlSecNodeGetName(node));
                 return(-1);
             }
@@ -415,10 +415,9 @@ xmlSecEncCtxXmlEncrypt(xmlSecEncCtxPtr encCtx, xmlNodePtr tmpl, xmlNodePtr node)
                 return(-1);
             }
         }
-
-            encCtx->resultReplaced = 1;
+        encCtx->resultReplaced = 1;
     } else if((encCtx->type != NULL) && xmlStrEqual(encCtx->type, xmlSecTypeEncContent)) {
-        /* check if we need to return the replaced node */
+    	/* check if we need to return the replaced node */
         if((encCtx->flags & XMLSEC_ENC_RETURN_REPLACED_NODE) != 0) {
             ret = xmlSecReplaceContentAndReturn(node, tmpl, &(encCtx->replacedNodeList));
             if(ret < 0) {
@@ -434,7 +433,6 @@ xmlSecEncCtxXmlEncrypt(xmlSecEncCtxPtr encCtx, xmlNodePtr tmpl, xmlNodePtr node)
                 return(-1);
             }
         }
-
         encCtx->resultReplaced = 1;
     } else {
         /* we should've caught this error before */
@@ -625,7 +623,7 @@ xmlSecEncCtxDecryptToBuffer(xmlSecEncCtxPtr encCtx, xmlNodePtr node) {
     } else {
         ret = xmlSecTransformCtxExecute(&(encCtx->transformCtx), node->doc);
         if(ret < 0) {
-            xmlSecInternalError("xmlSecTransformCtxBinaryExecute", NULL);
+            xmlSecInternalError("xmlSecTransformCtxExecute", NULL);
             return(NULL);
         }
     }
